import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import "x3m.js" as B

Page
{
    id: settingsPage
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait;

    property int streamQuality: 2;
    property alias bufferSize: sBufferSize.value;
    property alias useSurround: surround.checked;
    property alias loadImages: loadArtistImages.checked;

    Header {
        id: h
        text: qsTr("Settings");
    }

    Column {
        id: cs
        anchors.top: h.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left;
        anchors.right: parent.right
        anchors.topMargin: B.SMALL_MARGIN
        anchors.leftMargin: B.DEFAULT_MARGIN
        anchors.rightMargin: B.DEFAULT_MARGIN
        spacing: B.SMALL_MARGIN

        Label { text: qsTr("Stream quality"); anchors.left: parent.left; color: "white"; }
        ButtonRow {
            checkedButton: getChecked(streamQuality);
            exclusive: true;
            Button {
                id: sQualityMedium
                text: qsTr("Medium");
                onCheckedChanged: if (checked) streamQuality=2;
            }
            function getChecked(sq) {
                switch (sq) {
                case 1:
                    return sQualityLow
                case 2:
                    return sQualityMedium
                case 3:
                    return sQualityHigh
                default: {
                    streamQuality=2;
                    return sQualityMedium;
                }
                }
            }
        }
        Text {
            id: bitSize
            text: getBits(streamQuality);
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: 18
            anchors.left: parent.left;
            anchors.right: parent.right;
            color: "white";
            function getBits(sq) {
                switch (sq) {
                case 1:
                    return "64 - Mono"
                case 2:
                    return "128 - Stereo"
                case 3:
                    return "256 - Stereo"
                default: {
                    return "";
                }
                }
            }
        }
        Text {
            text: qsTr("High quality uses more bandwidth! Not recommended if you don't have an unlimited 3G data or use WiFi.");
            font.pixelSize: 20
            font.italic: true;
            anchors.left: parent.left;
            anchors.right: parent.right;
            color: "white";
            visible: sQualityHigh.checked;
            wrapMode: Text.WordWrap
        }

        Text {
            text: qsTr("Restart playback to use new quality setting.");
            font.pixelSize: 20
            anchors.left: parent.left;
            anchors.right: parent.right;
            color: "white";
            wrapMode: Text.WordWrap
        }

        Row {
            width: parent.width
            spacing: B.SMALL_MARGIN
            Label {
                text: qsTr("Load artist images");
                color: "white";
            }
            Switch {
                id: loadArtistImages
            }
        }

        Label { text: qsTr("Buffer size"); anchors.left: parent.left; color: "white"; }
        Slider {
            id: sBufferSize
            width: parent.width-42;
            maximumValue: 20;
            minimumValue: 5;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }

        Row {
            width: parent.width
            spacing: B.SMALL_MARGIN
            Label {
                text: qsTr("Surround");
                color: "white";
            }
            Switch {
                id: surround
            }
        }

        Label { text: qsTr("Brightness"); anchors.left: parent.left; color: "white"; visible: surround.checked; }
        Slider {
            id: sBright
            visible: surround.checked
            width: parent.width-42;
            maximumValue: 4;
            minimumValue: 0;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }

        Label { text: qsTr("Roomsize"); anchors.left: parent.left; color: "white"; visible: surround.checked; }
        Slider {
            id: sRoom
            visible: surround.checked
            width: parent.width-42;
            maximumValue: 4;
            minimumValue: 0;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }
    }
    property alias roomsize: sRoom.value;
    property alias brightness: sBright.value;
}
