import QtQuick 1.1
import com.nokia.meego 1.0
import org.tal.gst.http.player 1.0
import org.tal.gconf.item 1.0
import "x3m.js" as B

PageStackWindow {
    id: main
    initialPage: mainPage    

    property alias eq0: gconfEq0.value;
    property alias eq1: gconfEq1.value;
    property alias eq2: gconfEq2.value;

    property alias surround: gconfUseSurround.value;
    property alias brightness: gconfSurroundB.value;
    property alias roomsize: gconfSurroundRs.value;

    property alias playing: rPlayer.playing
    property alias connecting: rPlayer.connecting

    property alias bufferSize: gconfBufferSize.value;

    property alias quality: gconfStreamQuality.value;

    property alias loadImages: gconfLoadImages.value;

    GConfItem { id: gconfUseSurround; key: "/apps/xelyoidar/use_surround"; defaultValue: false; }
    GConfItem { id: gconfSurroundB; key: "/apps/xelyoidar/surround_br"; defaultValue: 2; }
    GConfItem { id: gconfSurroundRs; key: "/apps/xelyoidar/surround_rs"; defaultValue: 2; }

    GConfItem { id: gconfEq0; key: "/apps/xelyoidar/eq/0"; defaultValue: 0.0; }
    GConfItem { id: gconfEq1; key: "/apps/xelyoidar/eq/1"; defaultValue: 0.0; }
    GConfItem { id: gconfEq2; key: "/apps/xelyoidar/eq/2"; defaultValue: 0.0; }

    GConfItem { id: gconfBufferSize; key: "/apps/xelyoidar/buffer_size"; defaultValue: 5.0; }
    GConfItem { id: gconfVolume; key: "/apps/xelyoidar/volume"; defaultValue: 1.0; }

    GConfItem { id: gconfStreamQuality; key: "/apps/xelyoidar/quality"; defaultValue: 1; }

    GConfItem { id: gconfLoadImages; key: "/apps/xelyoidar/load_images"; defaultValue: true; }

    MainPage { id: mainPage; }
    About { id: aboutPage; }
    Settings {
        id: settingsPage;
        bufferSize: main.bufferSize;
        useSurround: main.surround;
        brightness: main.brightness;
        roomsize: main.roomsize;
        streamQuality: main.quality;
        loadImages: main.loadImages;

        onBufferSizeChanged: gconfBufferSize.value=bufferSize;
        onStreamQualityChanged: gconfStreamQuality.value=streamQuality;
        onBrightnessChanged: gconfSurroundB.value=brightness;
        onRoomsizeChanged: gconfSurroundRs.value=roomsize;
        onUseSurroundChanged: gconfUseSurround.value=useSurround;
        onLoadImagesChanged: gconfLoadImages.value=loadImages;
    }
    Equalizer {
        id: equalizerPage;
        eq0: main.eq0
        eq1: main.eq1
        eq2: main.eq2

        onEq0Changed: gconfEq0.value=eq0;
        onEq1Changed: gconfEq1.value=eq1;
        onEq2Changed: gconfEq2.value=eq2;
    }
    RadioFreq { id: freqPage; }
    ContactStudio { id: contactPage; }

    platformStyle: PageStackWindowStyle {
    background: '/opt/radiojavan/qml/xelyoidar/r.png'
        backgroundFillMode: Image.Stretch
    }

    HttpPlayer {
        id: rPlayer
        url: B.getStreamUrl(gconfStreamQuality.value);
        volume: gconfVolume.value;
        surround: gconfUseSurround.value;
        roomsize: gconfSurroundRs.value;
        brightness: gconfSurroundB.value;
        eqband0: gconfEq0.value;
        eqband1: gconfEq1.value;
        eqband2: gconfEq2.value;
        buffersize: gconfBufferSize.value;

        onErrorChanged: {
            if (error) {
                errorDialog.message=getError(ecode);
                errorDialog.open();
            }
        }

        // onWarningChanged: if (warning) displayBanner(false, wcode);
    }

    function getError(code)
    {
        switch (code) {
        case 7:
            return qsTr('Unable to connect');
        case 9:
            return qsTr('Read failure');
        default:
            return qsTr('fatal error');
        }
    }

    QueryDialog {
        id: errorDialog
        titleText: qsTr("Error");
        message: "";
        acceptButtonText: "OK"
    }

    MainToolbar {
        id: commonTools;
    }

    Menu {
        id: mainMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTr("Contact Radio Javan"); onClicked: { pageStack.push(contactPage); } }            
            MenuItem { text: qsTr("Equalizer"); onClicked: { pageStack.push(equalizerPage); } }
            MenuItem { text: qsTr("Settings"); onClicked: { pageStack.push(settingsPage); } }
            // MenuItem { text: qsTr("Frequencies"); onClicked: { pageStack.push(freqPage); } }
            MenuItem { text: qsTr("About"); onClicked: { pageStack.push(aboutPage); } }
        }
    }
}
